==> ccache_3.4.1.orig.tar.xz: ccache-3.4.1/README.md <==
ccache – a fast compiler cache
==============================

[![Build Status](https://travis-ci.org/ccache/ccache.svg?branch=master)](https://travis-ci.org/ccache/ccache)

ccache is a compiler cache. It speeds up recompilation by caching the result of
previous compilations and detecting when the same compilation is being done
again. Supported languages are C, C++, Objective-C and Objective-C++.


General information
-------------------

* [Main web site](https://ccache.samba.org)
* [Documentation](https://ccache.samba.org/documentation.html)
  * [Latest manual](https://ccache.samba.org/manual/latest.html)
  * [Installation from Git source repository](https://github.com/ccache/ccache/blob/master/doc/INSTALL.md)
  * [Installation from release archive](https://github.com/ccache/ccache/blob/master/doc/INSTALL-from-release-archive.md)
* [Release notes](https://ccache.samba.org/releasenotes.html)
* [Credits and history](https://ccache.samba.org/credits.html)
* [License and copyright](https://ccache.samba.org/license.html)


Contributing to ccache
----------------------

* [Source repository](https://github.com/ccache/ccache)
* [Notes on how to contribute](https://github.com/ccache/ccache/blob/master/CONTRIBUTING.md)
* [Mailing list](https://lists.samba.org/mailman/listinfo/ccache/)
* [Bug report info](https://ccache.samba.org/bugs.html)
* [Issue tracker](https://github.com/ccache/ccache/issues)
  * [Help wanted!](https://github.com/ccache/ccache/issues/help%20wanted)
  * [Good first issues!](https://github.com/ccache/ccache/issues/good%20first%20issue)

==> ccache-3.6.tar.xz: ccache-3.6/README.md <==
ccache – a fast compiler cache
==============================

[![Build Status](https://travis-ci.org/ccache/ccache.svg?branch=master)](https://travis-ci.org/ccache/ccache)
[![Code Quality: Cpp](https://img.shields.io/lgtm/grade/cpp/g/ccache/ccache.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/ccache/ccache/context:cpp)
[![Total Alerts](https://img.shields.io/lgtm/alerts/g/ccache/ccache.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/ccache/ccache/alerts)

ccache is a compiler cache. It speeds up recompilation by caching the result of
previous compilations and detecting when the same compilation is being done
again. Supported languages are C, C++, Objective-C and Objective-C++.


General information
-------------------

* [Main web site](https://ccache.samba.org)
* [Documentation](https://ccache.samba.org/documentation.html)
  * [Latest manual](https://ccache.samba.org/manual/latest.html)
  * [Installation from Git source repository](https://github.com/ccache/ccache/blob/master/doc/INSTALL.md)
  * [Installation from release archive](https://github.com/ccache/ccache/blob/master/doc/INSTALL-from-release-archive.md)
* [Release notes](https://ccache.samba.org/releasenotes.html)
* [Credits and history](https://ccache.samba.org/credits.html)
* [License and copyright](https://ccache.samba.org/license.html)


Contributing to ccache
----------------------

* [Source repository](https://github.com/ccache/ccache)
* [Notes on how to contribute](https://github.com/ccache/ccache/blob/master/CONTRIBUTING.md)
* [Mailing list](https://lists.samba.org/mailman/listinfo/ccache/)
* [Bug report info](https://ccache.samba.org/bugs.html)
* [Issue tracker](https://github.com/ccache/ccache/issues)
  * [Help wanted!](https://github.com/ccache/ccache/issues/help%20wanted)
  * [Good first issues!](https://github.com/ccache/ccache/issues/good%20first%20issue)
